<?php

$lan = array(
  'PHPList Users' => 'Usu&aacute;rios PHPList',
  'on' => 'na',
  'List Membership' => 'Lista de Membros',
  'No Lists' => 'Nenhuma Lista',
);
?>
